@@ -1,12 +1,9 @@
 //! # Examples
 //!
 //! ```rust,no_run
-//! use ashpd::{
-//!     desktop::{
-//!         remote_desktop::{DeviceType, KeyState, RemoteDesktop},
-//!         PersistMode,
-//!     },
-//!     WindowIdentifier,
+//! use ashpd::desktop::{
+//!     remote_desktop::{DeviceType, KeyState, RemoteDesktop},
+//!     PersistMode,
 //! };
 //!
 //! async fn run() -> ashpd::Result<()> {
@@ -21,10 +18,7 @@
 //!         )
 //!         .await?;
 //!
-//!     let response = proxy
-//!         .start(&session, &WindowIdentifier::default())
-//!         .await?
-//!         .response()?;
+//!     let response = proxy.start(&session, None).await?.response()?;
 //!     println!("{:#?}", response.devices());
 //!
 //!     // 13 for Enter key code
@@ -43,19 +37,15 @@
 //! [`RemoteDesktop::create_session()`][create_session]
 //!
 //! ```rust,no_run
-//! use ashpd::{
-//!     desktop::{
-//!         remote_desktop::{DeviceType, KeyState, RemoteDesktop},
-//!         screencast::{CursorMode, Screencast, SourceType},
-//!         PersistMode,
-//!     },
-//!     WindowIdentifier,
+//! use ashpd::desktop::{
+//!     remote_desktop::{DeviceType, KeyState, RemoteDesktop},
+//!     screencast::{CursorMode, Screencast, SourceType},
+//!     PersistMode,
 //! };
 //!
 //! async fn run() -> ashpd::Result<()> {
 //!     let remote_desktop = RemoteDesktop::new().await?;
 //!     let screencast = Screencast::new().await?;
-//!     let identifier = WindowIdentifier::default();
 //!     let session = remote_desktop.create_session().await?;
 //!
 //!     remote_desktop
@@ -77,10 +67,7 @@
 //!         )
 //!         .await?;
 //!
-//!     let response = remote_desktop
-//!         .start(&session, &identifier)
-//!         .await?
-//!         .response()?;
+//!     let response = remote_desktop.start(&session, None).await?.response()?;
 //!     println!("{:#?}", response.devices());
 //!     println!("{:#?}", response.streams());
 //!
@@ -310,9 +297,10 @@ impl<'a> RemoteDesktop<'a> {
     pub async fn start(
         &self,
         session: &Session<'_, Self>,
-        identifier: &WindowIdentifier,
+        identifier: Option<&WindowIdentifier>,
     ) -> Result<Request<SelectedDevices>, Error> {
         let options = StartRemoteOptions::default();
+        let identifier = identifier.map(|i| i.to_string()).unwrap_or_default();
         self.0
             .request(
                 &options.handle_token,
@@ -345,7 +333,7 @@ impl<'a> RemoteDesktop<'a> {
         state: KeyState,
     ) -> Result<(), Error> {
         // The `notify` methods don't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L723
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L837-L838
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         self.0
             .call("NotifyKeyboardKeycode", &(session, options, keycode, state))
@@ -375,7 +363,7 @@ impl<'a> RemoteDesktop<'a> {
         state: KeyState,
     ) -> Result<(), Error> {
         // The `notify` methods don't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L723
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L837-L838
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         self.0
             .call("NotifyKeyboardKeysym", &(session, options, keysym, state))
@@ -403,7 +391,7 @@ impl<'a> RemoteDesktop<'a> {
         slot: u32,
     ) -> Result<(), Error> {
         // The `notify` methods don't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L723
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L837-L838
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         self.0
             .call("NotifyTouchUp", &(session, options, slot))
@@ -439,7 +427,7 @@ impl<'a> RemoteDesktop<'a> {
         y: f64,
     ) -> Result<(), Error> {
         // The `notify` methods don't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L723
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L837-L838
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         self.0
             .call("NotifyTouchDown", &(session, options, stream, slot, x, y))
@@ -475,7 +463,7 @@ impl<'a> RemoteDesktop<'a> {
         y: f64,
     ) -> Result<(), Error> {
         // The `notify` methods don't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L723
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L837-L838
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         self.0
             .call("NotifyTouchMotion", &(session, options, stream, slot, x, y))
@@ -506,7 +494,7 @@ impl<'a> RemoteDesktop<'a> {
         y: f64,
     ) -> Result<(), Error> {
         // The `notify` methods don't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L723
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L837-L838
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         self.0
             .call(
@@ -538,7 +526,7 @@ impl<'a> RemoteDesktop<'a> {
         dy: f64,
     ) -> Result<(), Error> {
         // The `notify` methods don't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L723
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L837-L838
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         self.0
             .call("NotifyPointerMotion", &(session, options, dx, dy))
@@ -570,7 +558,7 @@ impl<'a> RemoteDesktop<'a> {
         state: KeyState,
     ) -> Result<(), Error> {
         // The `notify` methods don't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L723
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L837-L838
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         self.0
             .call("NotifyPointerButton", &(session, options, button, state))
@@ -599,7 +587,7 @@ impl<'a> RemoteDesktop<'a> {
         steps: i32,
     ) -> Result<(), Error> {
         // The `notify` methods don't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L723
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L837-L838
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         self.0
             .call(
@@ -637,7 +625,7 @@ impl<'a> RemoteDesktop<'a> {
         dy: f64,
         finish: bool,
     ) -> Result<(), Error> {
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L911
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L1025-L1027
         let mut options: HashMap<&str, Value<'_>> = HashMap::new();
         options.insert("finish", Value::Bool(finish));
         self.0
@@ -667,7 +655,7 @@ impl<'a> RemoteDesktop<'a> {
     #[doc(alias = "ConnectToEIS")]
     pub async fn connect_to_eis(&self, session: &Session<'_, Self>) -> Result<OwnedFd, Error> {
         // `ConnectToEIS` doesn't take any options for now
-        // see https://github.com/flatpak/xdg-desktop-portal/blob/master/src/remote-desktop.c#L1464
+        // see https://github.com/flatpak/xdg-desktop-portal/blob/1.20.0/src/remote-desktop.c#L1457-L1458
         let options: HashMap<&str, Value<'_>> = HashMap::new();
         let fd = self
             .0
@@ -695,4 +683,5 @@ impl<'a> std::ops::Deref for RemoteDesktop<'a> {
     }
 }
 
+impl crate::Sealed for RemoteDesktop<'_> {}
 impl SessionPortal for RemoteDesktop<'_> {}
