@@ -1,7 +1,7 @@
 //! # Examples
 //!
 //! ```rust,no_run
-//! use std::fs::File;
+//! use std::{fs::File, os::fd::AsFd};
 //!
 //! use ashpd::documents::FileTransfer;
 //!
@@ -10,7 +10,7 @@
 //!
 //!     let key = proxy.start_transfer(true, true).await?;
 //!     let file = File::open("/home/bilelmoussaoui/Downloads/adwaita-night.jpg").unwrap();
-//!     proxy.add_files(&key, &[&file]).await?;
+//!     proxy.add_files(&key, &[&file.as_fd()]).await?;
 //!
 //!     // The files would be retrieved by another process
 //!     let files = proxy.retrieve_files(&key).await?;
@@ -22,7 +22,7 @@
 //! }
 //! ```
 
-use std::{collections::HashMap, os::unix::prelude::AsRawFd};
+use std::{collections::HashMap, os::fd::AsFd};
 
 use futures_util::Stream;
 use zbus::zvariant::{Fd, SerializeDict, Type, Value};
@@ -72,7 +72,7 @@ impl TransferOptions {
 /// will take care of exporting files in the document store as necessary to make
 /// them accessible to the target.
 ///
-/// Wrapper of the DBus interface: [`org.freedesktop.portal.FileTransfer`](https://flatpak.github.io/xdg-desktop-portal/index.html#gdbus-org.freedesktop.portal.FileTransfer).
+/// Wrapper of the DBus interface: [`org.freedesktop.portal.FileTransfer`](https://flatpak.github.io/xdg-desktop-portal/docs/doc-org.freedesktop.portal.FileTransfer.html).
 #[derive(Debug)]
 #[doc(alias = "org.freedesktop.portal.FileTransfer")]
 pub struct FileTransfer<'a>(Proxy<'a>);
@@ -96,12 +96,12 @@ impl<'a> FileTransfer<'a> {
     ///
     /// # Specifications
     ///
-    /// See also [`AddFiles`](https://flatpak.github.io/xdg-desktop-portal/index.html#gdbus-method-org-freedesktop-portal-FileTransfer.AddFiles).
+    /// See also [`AddFiles`](https://flatpak.github.io/xdg-desktop-portal/docs/doc-org.freedesktop.portal.FileTransfer.html#org-freedesktop-portal-filetransfer-addfiles).
     #[doc(alias = "AddFiles")]
-    pub async fn add_files(&self, key: &str, fds: &[&impl AsRawFd]) -> Result<(), Error> {
+    pub async fn add_files(&self, key: &str, fds: &[impl AsFd]) -> Result<(), Error> {
         // `options` parameter doesn't seems to be used yet
         let options: HashMap<&str, Value<'_>> = HashMap::new();
-        let files: Vec<Fd> = fds.iter().map(|f| Fd::from(f.as_raw_fd())).collect();
+        let files: Vec<Fd> = fds.iter().map(Fd::from).collect();
 
         self.0.call("AddFiles", &(key, files, options)).await
     }
@@ -122,11 +122,11 @@ impl<'a> FileTransfer<'a> {
     ///
     /// # Specifications
     ///
-    /// See also [`RetrieveFiles`](https://flatpak.github.io/xdg-desktop-portal/index.html#gdbus-method-org-freedesktop-portal-FileTransfer.RetrieveFiles).
+    /// See also [`RetrieveFiles`](https://flatpak.github.io/xdg-desktop-portal/docs/doc-org.freedesktop.portal.FileTransfer.html#org-freedesktop-portal-filetransfer-retrievefiles).
     #[doc(alias = "RetrieveFiles")]
     pub async fn retrieve_files(&self, key: &str) -> Result<Vec<String>, Error> {
         // `options` parameter doesn't seems to be used yet
-        // see https://github.com/GNOME/gtk/blob/master/gdk/filetransferportal.c#L284
+        // see https://github.com/GNOME/gtk/blob/4.16.12/gdk/filetransferportal.c#L288
         let options: HashMap<&str, Value<'_>> = HashMap::new();
 
         self.0.call("RetrieveFiles", &(key, options)).await
@@ -151,7 +151,7 @@ impl<'a> FileTransfer<'a> {
     ///
     /// # Specifications
     ///
-    /// See also [`StartTransfer`](https://flatpak.github.io/xdg-desktop-portal/index.html#gdbus-method-org-freedesktop-portal-FileTransfer.StartTransfer).
+    /// See also [`StartTransfer`](https://flatpak.github.io/xdg-desktop-portal/docs/doc-org.freedesktop.portal.FileTransfer.html#org-freedesktop-portal-filetransfer-starttransfer).
     pub async fn start_transfer(&self, writeable: bool, auto_stop: bool) -> Result<String, Error> {
         let options = TransferOptions::default()
             .writeable(writeable)
@@ -171,7 +171,7 @@ impl<'a> FileTransfer<'a> {
     ///
     /// # Specifications
     ///
-    /// See also [`StopTransfer`](https://flatpak.github.io/xdg-desktop-portal/index.html#gdbus-method-org-freedesktop-portal-FileTransfer.StopTransfer).
+    /// See also [`StopTransfer`](https://flatpak.github.io/xdg-desktop-portal/docs/doc-org.freedesktop.portal.FileTransfer.html#org-freedesktop-portal-filetransfer-stoptransfer).
     #[doc(alias = "StopTransfer")]
     pub async fn stop_transfer(&self, key: &str) -> Result<(), Error> {
         self.0.call("StopTransfer", &(key)).await
@@ -186,9 +186,17 @@ impl<'a> FileTransfer<'a> {
     ///
     /// # Specifications
     ///
-    /// See also [`TransferClosed`](https://flatpak.github.io/xdg-desktop-portal/index.html#gdbus-signal-org-freedesktop-portal-FileTransfer.TransferClosed).
+    /// See also [`TransferClosed`](https://flatpak.github.io/xdg-desktop-portal/docs/doc-org.freedesktop.portal.FileTransfer.html#org-freedesktop-portal-filetransfer-transferclosed).
     #[doc(alias = "TransferClosed")]
     pub async fn transfer_closed(&self) -> Result<impl Stream<Item = String>, Error> {
         self.0.signal("TransferClosed").await
     }
 }
+
+impl<'a> std::ops::Deref for FileTransfer<'a> {
+    type Target = zbus::Proxy<'a>;
+
+    fn deref(&self) -> &Self::Target {
+        &self.0
+    }
+}
